### Name: predict.kohonen
### Title: Predict properties using a trained Kohonen map
### Aliases: predict.kohonen
### Keywords: classif

### ** Examples

data(wines)
set.seed(7)

training <- sample(nrow(wines), 120)
Xtraining <- scale(wines[training, ])
Xtest <- scale(wines[-training, ],
               center = attr(Xtraining, "scaled:center"),
               scale = attr(Xtraining, "scaled:scale"))

som.wines <- som(Xtraining, grid = somgrid(5, 5, "hexagonal"))

som.prediction <- predict(som.wines, newdata = Xtest,
          trainX = Xtraining,
          trainY = factor(wine.classes[training]))
table(wine.classes[-training], som.prediction$prediction)

### more complicated examples
## Not run: 
##D data(yeast)
##D 
##D ### only consider complete cases
##D missings <- (apply(cbind(yeast$alpha, yeast$cdc15), 1,
##D                    function(x) any(is.na(x))))
##D 
##D yeast2 <- list(alpha = yeast$alpha[!missings,],
##D                cdc15 = yeast$cdc15[!missings,],
##D                class = yeast$class[!missings])
##D 
##D set.seed(7)
##D training.indices <- sample(nrow(yeast2$alpha), 300)
##D training <- rep(FALSE, nrow(yeast2$alpha))
##D training[training.indices] <- TRUE
##D 
##D ## unsupervised mapping
##D yeast2.som <- som(yeast2$alpha[training,], somgrid(4, 6, "hexagonal"))
##D yeast2.som.prediction <- predict(yeast2.som,
##D                                  newdata = yeast2$alpha[!training,],
##D                                  trainY = yeast2$class[training])
##D predicted.classes <- yeast2.som.prediction$prediction
##D 
##D ## supervised mapping (XYF)
##D yeast2.xyf <- xyf(yeast2$alpha[training,], yeast2$class[training],
##D                   somgrid(4, 6, "hexagonal"))
##D yeast2.xyf.prediction <- predict(yeast2.xyf,
##D                                  newdata = yeast2$alpha[!training,])
##D 
##D ## supervised mapping (BDK)
##D yeast2.bdk <- bdk(yeast2$alpha[training,], yeast2$class[training],
##D                   somgrid(4, 6, "hexagonal"))
##D yeast2.bdk.prediction <- predict(yeast2.bdk,
##D                                  newdata = yeast2$alpha[!training,])
##D 
##D ## unsupervised mapping (supersom): prediction of data layer not used
##D ## in training
##D yeast2.ssom <- supersom(lapply(yeast2, function(x) subset(x, training)),
##D                         grid = somgrid(4, 6, "hexagonal"),
##D                         whatmap = 1)
##D yeast2.ssom.prediction <- predict(yeast2.ssom,
##D                                   newdata = lapply(yeast2,
##D                                     function(x) subset(x, !training)),
##D                                   trainY = list(class = yeast2$class[training]))
##D 
##D ## supervised mapping (supersom): prediction of a data layer that has
##D ## been used in training
##D yeast2.ssom2 <- supersom(lapply(yeast2, function(x) subset(x, training)),
##D                          grid = somgrid(4, 6, "hexagonal"),
##D                          whatmap = c(1,3))
##D yeast2.ssom2.prediction <- predict(yeast2.ssom2, 
##D                                    newdata = lapply(yeast2,
##D                                      function(x) subset(x, !training)),
##D                                    whatmap = 1)
## End(Not run)




